# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/opensearch/v1/backup.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/opensearch/v1/backup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/mdb/opensearch/v1/backup.proto\x12\x1eyandex.cloud.mdb.opensearch.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xe2\x02\n\x06\x42\x61\x63kup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x19\n\x11source_cluster_id\x18\x03 \x01(\t\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x07indices\x18\x06 \x03(\tB\t\x82\xc8\x31\x05<=100\x12\x1a\n\x12opensearch_version\x18\x07 \x01(\t\x12\x12\n\nsize_bytes\x18\x08 \x01(\x03\x12\x15\n\rindices_total\x18\t \x01(\x03\x12\x1e\n\x16incremental_size_bytes\x18\n \x01(\x03\x12\x18\n\x10total_size_bytes\x18\x0b \x01(\x03\x12!\n\x19\x66ree_space_required_bytes\x18\x0c \x01(\x03\"\xa6\x01\n\x12SnapshotManagement\x12K\n\x11snapshot_schedule\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.opensearch.v1.SnapshotSchedule\x12\x43\n\x15snapshot_max_age_days\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=7\"\xb6\x02\n\x10SnapshotSchedule\x12Z\n\x18hourly_snapshot_schedule\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.opensearch.v1.HourlySnapshotScheduleH\x00\x12X\n\x17\x64\x61ily_snapshot_schedule\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.opensearch.v1.DailySnapshotScheduleH\x00\x12Z\n\x18weekly_snapshot_schedule\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.mdb.opensearch.v1.WeeklySnapshotScheduleH\x00\x42\x10\n\x08schedule\x12\x04\xc0\xc1\x31\x01\"2\n\x16HourlySnapshotSchedule\x12\x18\n\x06minute\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-59\"I\n\x15\x44\x61ilySnapshotSchedule\x12\x16\n\x04hour\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-23\x12\x18\n\x06minute\x18\x02 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-59\"\xfb\x01\n\x16WeeklySnapshotSchedule\x12K\n\x03\x64\x61y\x18\x01 \x01(\x0e\x32>.yandex.cloud.mdb.opensearch.v1.WeeklySnapshotSchedule.WeekDay\x12\x16\n\x04hour\x18\x02 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-23\x12\x18\n\x06minute\x18\x03 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-59\"b\n\x07WeekDay\x12\x18\n\x14WEEK_DAY_UNSPECIFIED\x10\x00\x12\x07\n\x03MON\x10\x01\x12\x07\n\x03TUE\x10\x02\x12\x07\n\x03WED\x10\x03\x12\x07\n\x03THU\x10\x04\x12\x07\n\x03\x46RI\x10\x05\x12\x07\n\x03SAT\x10\x06\x12\x07\n\x03SUN\x10\x07\x42s\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.opensearch.v1.backup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearch'
  _globals['_BACKUP'].fields_by_name['indices']._loaded_options = None
  _globals['_BACKUP'].fields_by_name['indices']._serialized_options = b'\202\3101\005<=100'
  _globals['_SNAPSHOTMANAGEMENT'].fields_by_name['snapshot_max_age_days']._loaded_options = None
  _globals['_SNAPSHOTMANAGEMENT'].fields_by_name['snapshot_max_age_days']._serialized_options = b'\372\3071\003>=7'
  _globals['_SNAPSHOTSCHEDULE'].oneofs_by_name['schedule']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULE'].oneofs_by_name['schedule']._serialized_options = b'\300\3011\001'
  _globals['_HOURLYSNAPSHOTSCHEDULE'].fields_by_name['minute']._loaded_options = None
  _globals['_HOURLYSNAPSHOTSCHEDULE'].fields_by_name['minute']._serialized_options = b'\372\3071\0040-59'
  _globals['_DAILYSNAPSHOTSCHEDULE'].fields_by_name['hour']._loaded_options = None
  _globals['_DAILYSNAPSHOTSCHEDULE'].fields_by_name['hour']._serialized_options = b'\372\3071\0040-23'
  _globals['_DAILYSNAPSHOTSCHEDULE'].fields_by_name['minute']._loaded_options = None
  _globals['_DAILYSNAPSHOTSCHEDULE'].fields_by_name['minute']._serialized_options = b'\372\3071\0040-59'
  _globals['_WEEKLYSNAPSHOTSCHEDULE'].fields_by_name['hour']._loaded_options = None
  _globals['_WEEKLYSNAPSHOTSCHEDULE'].fields_by_name['hour']._serialized_options = b'\372\3071\0040-23'
  _globals['_WEEKLYSNAPSHOTSCHEDULE'].fields_by_name['minute']._loaded_options = None
  _globals['_WEEKLYSNAPSHOTSCHEDULE'].fields_by_name['minute']._serialized_options = b'\372\3071\0040-59'
  _globals['_BACKUP']._serialized_start=176
  _globals['_BACKUP']._serialized_end=530
  _globals['_SNAPSHOTMANAGEMENT']._serialized_start=533
  _globals['_SNAPSHOTMANAGEMENT']._serialized_end=699
  _globals['_SNAPSHOTSCHEDULE']._serialized_start=702
  _globals['_SNAPSHOTSCHEDULE']._serialized_end=1012
  _globals['_HOURLYSNAPSHOTSCHEDULE']._serialized_start=1014
  _globals['_HOURLYSNAPSHOTSCHEDULE']._serialized_end=1064
  _globals['_DAILYSNAPSHOTSCHEDULE']._serialized_start=1066
  _globals['_DAILYSNAPSHOTSCHEDULE']._serialized_end=1139
  _globals['_WEEKLYSNAPSHOTSCHEDULE']._serialized_start=1142
  _globals['_WEEKLYSNAPSHOTSCHEDULE']._serialized_end=1393
  _globals['_WEEKLYSNAPSHOTSCHEDULE_WEEKDAY']._serialized_start=1295
  _globals['_WEEKLYSNAPSHOTSCHEDULE_WEEKDAY']._serialized_end=1393
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v1/folder_budget_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v1/folder_budget_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/datasphere/v1/folder_budget_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"9\n\x16GetFolderBudgetRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xc3\x01\n\x17GetFolderBudgetResponse\x12\x31\n\x0cunit_balance\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12max_units_per_hour\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17max_units_per_execution\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x91\x02\n\x16SetFolderBudgetRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x08set_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x0cunit_balance\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12max_units_per_hour\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17max_units_per_execution\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value2\xc3\x02\n\x13\x46olderBudgetService\x12\xa1\x01\n\x03Get\x12\x32.yandex.cloud.datasphere.v1.GetFolderBudgetRequest\x1a\x33.yandex.cloud.datasphere.v1.GetFolderBudgetResponse\"1\x82\xd3\xe4\x93\x02+\x12)/datasphere/v1/folders/{folder_id}:budget\x12\x87\x01\n\x03Set\x12\x32.yandex.cloud.datasphere.v1.SetFolderBudgetRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\")/datasphere/v1/folders/{folder_id}:budget:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.folder_budget_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _globals['_GETFOLDERBUDGETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETFOLDERBUDGETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETFOLDERBUDGETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_SETFOLDERBUDGETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FOLDERBUDGETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_FOLDERBUDGETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/datasphere/v1/folders/{folder_id}:budget'
  _globals['_FOLDERBUDGETSERVICE'].methods_by_name['Set']._loaded_options = None
  _globals['_FOLDERBUDGETSERVICE'].methods_by_name['Set']._serialized_options = b'\202\323\344\223\002.\")/datasphere/v1/folders/{folder_id}:budget:\001*'
  _globals['_GETFOLDERBUDGETREQUEST']._serialized_start=242
  _globals['_GETFOLDERBUDGETREQUEST']._serialized_end=299
  _globals['_GETFOLDERBUDGETRESPONSE']._serialized_start=302
  _globals['_GETFOLDERBUDGETRESPONSE']._serialized_end=497
  _globals['_SETFOLDERBUDGETREQUEST']._serialized_start=500
  _globals['_SETFOLDERBUDGETREQUEST']._serialized_end=773
  _globals['_FOLDERBUDGETSERVICE']._serialized_start=776
  _globals['_FOLDERBUDGETSERVICE']._serialized_end=1099
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadtesting.api.v1.agent.agent_pb2
import yandex.cloud.loadtesting.api.v1.agent_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AgentServiceStub:
    """A set of methods for managing Load Testing agents."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.CreateAgentRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an agent in the specified folder.

    Also creates a corresponding compute instance.
    """

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.GetAgentRequest,
        yandex.cloud.loadtesting.api.v1.agent.agent_pb2.Agent,
    ]
    """Returns the specified agent.

    To get the list of all available agents, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.ListAgentsRequest,
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.ListAgentsResponse,
    ]
    """Retrieves the list of agents in the specified folder."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.DeleteAgentRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified agent.

    Also deletes a corresponding compute instance.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.UpdateAgentRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified agent."""

class AgentServiceAsyncStub:
    """A set of methods for managing Load Testing agents."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.CreateAgentRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an agent in the specified folder.

    Also creates a corresponding compute instance.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.GetAgentRequest,
        yandex.cloud.loadtesting.api.v1.agent.agent_pb2.Agent,
    ]
    """Returns the specified agent.

    To get the list of all available agents, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.ListAgentsRequest,
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.ListAgentsResponse,
    ]
    """Retrieves the list of agents in the specified folder."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.DeleteAgentRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified agent.

    Also deletes a corresponding compute instance.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.agent_service_pb2.UpdateAgentRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified agent."""

class AgentServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Load Testing agents."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.loadtesting.api.v1.agent_service_pb2.CreateAgentRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an agent in the specified folder.

        Also creates a corresponding compute instance.
        """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.loadtesting.api.v1.agent_service_pb2.GetAgentRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.agent.agent_pb2.Agent, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.agent.agent_pb2.Agent]]:
        """Returns the specified agent.

        To get the list of all available agents, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.loadtesting.api.v1.agent_service_pb2.ListAgentsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.agent_service_pb2.ListAgentsResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.agent_service_pb2.ListAgentsResponse]]:
        """Retrieves the list of agents in the specified folder."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.loadtesting.api.v1.agent_service_pb2.DeleteAgentRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified agent.

        Also deletes a corresponding compute instance.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.loadtesting.api.v1.agent_service_pb2.UpdateAgentRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified agent."""

def add_AgentServiceServicer_to_server(servicer: AgentServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UsedNetwork(google.protobuf.message.Message):
    """A VPC network used in serverless resources."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UsedNetwork._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: UsedNetwork._Status.ValueType  # 0
        CREATING: UsedNetwork._Status.ValueType  # 1
        """Network is connecting to its first serverless resource."""
        ACTIVE: UsedNetwork._Status.ValueType  # 2
        """Network is already being used by some serverless resources."""
        OBSOLETE: UsedNetwork._Status.ValueType  # 3
        """Network is no longer used by any serverless resources.
        It will be cleaned-up after a while.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: UsedNetwork.Status.ValueType  # 0
    CREATING: UsedNetwork.Status.ValueType  # 1
    """Network is connecting to its first serverless resource."""
    ACTIVE: UsedNetwork.Status.ValueType  # 2
    """Network is already being used by some serverless resources."""
    OBSOLETE: UsedNetwork.Status.ValueType  # 3
    """Network is no longer used by any serverless resources.
    It will be cleaned-up after a while.
    """

    NETWORK_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    WILL_BE_CLEANED_UP_AT_FIELD_NUMBER: builtins.int
    CONNECTIONS_COUNT_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the VPC network."""
    cloud_id: builtins.str
    """ID of the cloud that the network belongs to."""
    folder_id: builtins.str
    """ID of the folder that the network belongs to."""
    status: global___UsedNetwork.Status.ValueType
    """Status of the network."""
    connections_count: builtins.int
    """Number of serverless resources connected to the network."""
    @property
    def will_be_cleaned_up_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Clean-up timestamp of the obsolete network."""

    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        status: global___UsedNetwork.Status.ValueType = ...,
        will_be_cleaned_up_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        connections_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["will_be_cleaned_up_at", b"will_be_cleaned_up_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "connections_count", b"connections_count", "folder_id", b"folder_id", "network_id", b"network_id", "status", b"status", "will_be_cleaned_up_at", b"will_be_cleaned_up_at"]) -> None: ...

global___UsedNetwork = UsedNetwork

@typing.final
class GetUsedNetworkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the network to return."""
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id"]) -> None: ...

global___GetUsedNetworkRequest = GetUsedNetworkRequest

@typing.final
class ListUsedNetworksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `pageSize`, the service returns a [ListUsedNetworksResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListUsedNetworksResponse.next_page_token] returned by a previous list request.
    """
    cloud_id: builtins.str
    """ID of the cloud to list used networks in."""
    folder_id: builtins.str
    """ID of the folder to list used networks in."""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "folder_id", b"folder_id", "scope", b"scope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token", "scope", b"scope"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["scope", b"scope"]) -> typing.Literal["cloud_id", "folder_id"] | None: ...

global___ListUsedNetworksRequest = ListUsedNetworksRequest

@typing.final
class ListUsedNetworksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListUsedNetworksRequest.page_size], use `nextPageToken` as the value
    for the [ListUsedNetworksRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsedNetwork]:
        """List of used networks in the specified scope."""

    def __init__(
        self,
        *,
        networks: collections.abc.Iterable[global___UsedNetwork] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["networks", b"networks", "next_page_token", b"next_page_token"]) -> None: ...

global___ListUsedNetworksResponse = ListUsedNetworksResponse

@typing.final
class ListConnectedResourcesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `pageSize`, the service returns a [ListConnectedResourcesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListConnectedResourcesResponse.next_page_token] returned by a previous list request.
    """
    network_id: builtins.str
    """ID of the network to list serverless resources connected to it."""
    cloud_id: builtins.str
    """ID of the cloud to list serverless resources connected to any network from it."""
    folder_id: builtins.str
    """ID of the folder to list serverless resources connected to any network from it."""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        network_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "folder_id", b"folder_id", "network_id", b"network_id", "network_scope", b"network_scope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "folder_id", b"folder_id", "network_id", b"network_id", "network_scope", b"network_scope", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["network_scope", b"network_scope"]) -> typing.Literal["network_id", "cloud_id", "folder_id"] | None: ...

global___ListConnectedResourcesRequest = ListConnectedResourcesRequest

@typing.final
class ListConnectedResourcesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ConnectedResource(google.protobuf.message.Message):
        """Serverless resource connected to VPC network."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NETWORK_ID_FIELD_NUMBER: builtins.int
        RESOURCE_TYPE_FIELD_NUMBER: builtins.int
        RESOURCE_ID_FIELD_NUMBER: builtins.int
        SUBRESOURCE_TYPE_FIELD_NUMBER: builtins.int
        SUBRESOURCE_ID_FIELD_NUMBER: builtins.int
        RESOURCE_CLOUD_ID_FIELD_NUMBER: builtins.int
        RESOURCE_FOLDER_ID_FIELD_NUMBER: builtins.int
        network_id: builtins.str
        """ID of the network to which the resource is connected."""
        resource_type: builtins.str
        """Type of the serverless resource."""
        resource_id: builtins.str
        """ID of the serverless resource."""
        subresource_type: builtins.str
        """Type of the serverless subresource."""
        subresource_id: builtins.str
        """ID of the serverless subresource."""
        resource_cloud_id: builtins.str
        """ID of the cloud that the resource belongs to."""
        resource_folder_id: builtins.str
        """ID of the folder thar the resource belongs to."""
        def __init__(
            self,
            *,
            network_id: builtins.str = ...,
            resource_type: builtins.str = ...,
            resource_id: builtins.str = ...,
            subresource_type: builtins.str = ...,
            subresource_id: builtins.str = ...,
            resource_cloud_id: builtins.str = ...,
            resource_folder_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "resource_cloud_id", b"resource_cloud_id", "resource_folder_id", b"resource_folder_id", "resource_id", b"resource_id", "resource_type", b"resource_type", "subresource_id", b"subresource_id", "subresource_type", b"subresource_type"]) -> None: ...

    RESOURCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListConnectedResourcesRequest.page_size], use `nextPageToken` as the value
    for the [ListConnectedResourcesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListConnectedResourcesResponse.ConnectedResource]:
        """List of serverless resources connected to any network from the specified scope."""

    def __init__(
        self,
        *,
        resources: collections.abc.Iterable[global___ListConnectedResourcesResponse.ConnectedResource] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "resources", b"resources"]) -> None: ...

global___ListConnectedResourcesResponse = ListConnectedResourcesResponse

@typing.final
class TriggerUsedNetworkCleanupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the obsolete network to start the cleanup process for."""
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id"]) -> None: ...

global___TriggerUsedNetworkCleanupRequest = TriggerUsedNetworkCleanupRequest

@typing.final
class TriggerUsedNetworkCleanupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_CLEANUP_TIME_FIELD_NUMBER: builtins.int
    @property
    def network_cleanup_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when cleanup of the specified network will be started."""

    def __init__(
        self,
        *,
        network_cleanup_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["network_cleanup_time", b"network_cleanup_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["network_cleanup_time", b"network_cleanup_time"]) -> None: ...

global___TriggerUsedNetworkCleanupResponse = TriggerUsedNetworkCleanupResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ytsaurus.v1.cluster_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to return."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list clusters in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListClustersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListClustersResponse.next_page_token] returned by a previous list request.
    """
    @property
    def filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A filter expression that filters clusters listed in the response."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClustersRequest.page_size], use the [next_page_token] as the value
    for the [ListClustersRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ytsaurus.v1.cluster_pb2.Cluster]:
        """List of clusters in the specified folder."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.ytsaurus.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create the cluster in."""
    zone_id: builtins.str
    """ID of the availability zone where the cluster resides."""
    name: builtins.str
    """Name of the cluster."""
    description: builtins.str
    """Description of the cluster."""
    subnet_id: builtins.str
    """ID of the subnet to create the cluster in."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Cluster labels as `key:value` pairs."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the security groups to attach to the cluster."""

    @property
    def spec(self) -> yandex.cloud.ytsaurus.v1.cluster_pb2.ClusterSpec:
        """Cluster specification."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        spec: yandex.cloud.ytsaurus.v1.cluster_pb2.ClusterSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "security_group_ids", b"security_group_ids", "spec", b"spec", "subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to update."""
    name: builtins.str
    """New name for the cluster.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description for the cluster."""
    subnet_id: builtins.str
    """New subnet for the cluster."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the cluster should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Cluster labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [ClusterService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """New security groups for the cluster."""

    @property
    def spec(self) -> yandex.cloud.ytsaurus.v1.cluster_pb2.ClusterSpec:
        """New cluster specification."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        spec: yandex.cloud.ytsaurus.v1.cluster_pb2.ClusterSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["spec", b"spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "description", b"description", "labels", b"labels", "name", b"name", "security_group_ids", b"security_group_ids", "spec", b"spec", "subnet_id", b"subnet_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to start."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that is being started."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to stop."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that is being stopped."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.image_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource to return.

    To get the image ID, use a [ImageService.List] request.
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___GetImageRequest = GetImageRequest

@typing.final
class ListImagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list images in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListConfigurationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListConfigurationsResponse.next_page_token] returned by a previous list request.
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Supported fields: ["id", "name", "createdAt"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=` (equal), `:` (substring).
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["id", "name"].
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListImagesRequest = ListImagesRequest

@typing.final
class ListImagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListImagesRequest.page_size], use `next_page_token` as the value
    for the [ListImagesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.image_pb2.Image]:
        """List of Image resources."""

    def __init__(
        self,
        *,
        images: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.image_pb2.Image] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["images", b"images", "next_page_token", b"next_page_token"]) -> None: ...

global___ListImagesResponse = ListImagesResponse

@typing.final
class CreateImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an image in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the image.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the image."""
    uri: builtins.str
    """URI of the source image to create the new image from.
    Currently only supports links to images that are stored in Object Storage.
    Currently only supports ISO formats.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        uri: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "uri", b"uri"]) -> None: ...

global___CreateImageRequest = CreateImageRequest

@typing.final
class CreateImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image that is being created."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___CreateImageMetadata = CreateImageMetadata

@typing.final
class UpdateImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource to update.

    To get the image ID, use a [ImageService.List] request.
    """
    name: builtins.str
    """Name of the image.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the image."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Image resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "image_id", b"image_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateImageRequest = UpdateImageRequest

@typing.final
class UpdateImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource that is being updated."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___UpdateImageMetadata = UpdateImageMetadata

@typing.final
class DeleteImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image to delete.

    To get the image ID, use a [ImageService.List] request.
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___DeleteImageRequest = DeleteImageRequest

@typing.final
class DeleteImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource that is being deleted."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___DeleteImageMetadata = DeleteImageMetadata

@typing.final
class ListImageOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListImageOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListImageOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListImageOperationsRequest = ListImageOperationsRequest

@typing.final
class ListImageOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListImageOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListImageOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified Image resource."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListImageOperationsResponse = ListImageOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateTrailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    job_id: builtins.str
    agent_instance_id: builtins.str
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail]: ...
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        data: collections.abc.Iterable[global___Trail] | None = ...,
        job_id: builtins.str = ...,
        agent_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id", "compute_instance_id", b"compute_instance_id", "data", b"data", "job_id", b"job_id"]) -> None: ...

global___CreateTrailRequest = CreateTrailRequest

@typing.final
class Trail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Codes(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CODE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        code: builtins.int
        count: builtins.int
        def __init__(
            self,
            *,
            code: builtins.int = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["code", b"code", "count", b"count"]) -> None: ...

    @typing.final
    class Intervals(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TO_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        to: builtins.float
        count: builtins.int
        def __init__(
            self,
            *,
            to: builtins.float = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "to", b"to"]) -> None: ...

    OVERALL_FIELD_NUMBER: builtins.int
    CASE_ID_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    REQPS_FIELD_NUMBER: builtins.int
    RESPS_FIELD_NUMBER: builtins.int
    EXPECT_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    CONNECT_TIME_FIELD_NUMBER: builtins.int
    SEND_TIME_FIELD_NUMBER: builtins.int
    LATENCY_FIELD_NUMBER: builtins.int
    RECEIVE_TIME_FIELD_NUMBER: builtins.int
    THREADS_FIELD_NUMBER: builtins.int
    Q50_FIELD_NUMBER: builtins.int
    Q75_FIELD_NUMBER: builtins.int
    Q80_FIELD_NUMBER: builtins.int
    Q85_FIELD_NUMBER: builtins.int
    Q90_FIELD_NUMBER: builtins.int
    Q95_FIELD_NUMBER: builtins.int
    Q98_FIELD_NUMBER: builtins.int
    Q99_FIELD_NUMBER: builtins.int
    Q100_FIELD_NUMBER: builtins.int
    HTTP_CODES_FIELD_NUMBER: builtins.int
    NET_CODES_FIELD_NUMBER: builtins.int
    TIME_INTERVALS_FIELD_NUMBER: builtins.int
    overall: builtins.int
    case_id: builtins.str
    time: builtins.str
    reqps: builtins.int
    resps: builtins.int
    expect: builtins.float
    input: builtins.int
    output: builtins.int
    connect_time: builtins.float
    send_time: builtins.float
    latency: builtins.float
    receive_time: builtins.float
    threads: builtins.int
    q50: builtins.float
    q75: builtins.float
    q80: builtins.float
    q85: builtins.float
    q90: builtins.float
    q95: builtins.float
    q98: builtins.float
    q99: builtins.float
    q100: builtins.float
    @property
    def http_codes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.Codes]: ...
    @property
    def net_codes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.Codes]: ...
    @property
    def time_intervals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.Intervals]: ...
    def __init__(
        self,
        *,
        overall: builtins.int = ...,
        case_id: builtins.str = ...,
        time: builtins.str = ...,
        reqps: builtins.int = ...,
        resps: builtins.int = ...,
        expect: builtins.float = ...,
        input: builtins.int = ...,
        output: builtins.int = ...,
        connect_time: builtins.float = ...,
        send_time: builtins.float = ...,
        latency: builtins.float = ...,
        receive_time: builtins.float = ...,
        threads: builtins.int = ...,
        q50: builtins.float = ...,
        q75: builtins.float = ...,
        q80: builtins.float = ...,
        q85: builtins.float = ...,
        q90: builtins.float = ...,
        q95: builtins.float = ...,
        q98: builtins.float = ...,
        q99: builtins.float = ...,
        q100: builtins.float = ...,
        http_codes: collections.abc.Iterable[global___Trail.Codes] | None = ...,
        net_codes: collections.abc.Iterable[global___Trail.Codes] | None = ...,
        time_intervals: collections.abc.Iterable[global___Trail.Intervals] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["case_id", b"case_id", "connect_time", b"connect_time", "expect", b"expect", "http_codes", b"http_codes", "input", b"input", "latency", b"latency", "net_codes", b"net_codes", "output", b"output", "overall", b"overall", "q100", b"q100", "q50", b"q50", "q75", b"q75", "q80", b"q80", "q85", b"q85", "q90", b"q90", "q95", b"q95", "q98", b"q98", "q99", b"q99", "receive_time", b"receive_time", "reqps", b"reqps", "resps", b"resps", "send_time", b"send_time", "threads", b"threads", "time", b"time", "time_intervals", b"time_intervals"]) -> None: ...

global___Trail = Trail

@typing.final
class CreateTrailResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRAIL_ID_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    trail_id: builtins.str
    code: builtins.int
    def __init__(
        self,
        *,
        trail_id: builtins.str = ...,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "trail_id", b"trail_id"]) -> None: ...

global___CreateTrailResponse = CreateTrailResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.apploadbalancer.v1.backend_group_pb2
import yandex.cloud.apploadbalancer.v1.backend_group_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BackendGroupServiceStub:
    """A set of methods for managing backend groups."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.GetBackendGroupRequest,
        yandex.cloud.apploadbalancer.v1.backend_group_pb2.BackendGroup,
    ]
    """Returns the specified backend group.

    To get the list of all available backend groups, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupsRequest,
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupsResponse,
    ]
    """Lists backend groups in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.CreateBackendGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a backend group in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.UpdateBackendGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified backend group."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.DeleteBackendGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified backend group."""

    AddBackend: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.AddBackendRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds backends to the specified backend group."""

    RemoveBackend: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.RemoveBackendRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes backends from the specified backend group."""

    UpdateBackend: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.UpdateBackendRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified backend."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupOperationsRequest,
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupOperationsResponse,
    ]
    """Lists operations for the specified backend group."""

class BackendGroupServiceAsyncStub:
    """A set of methods for managing backend groups."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.GetBackendGroupRequest,
        yandex.cloud.apploadbalancer.v1.backend_group_pb2.BackendGroup,
    ]
    """Returns the specified backend group.

    To get the list of all available backend groups, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupsRequest,
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupsResponse,
    ]
    """Lists backend groups in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.CreateBackendGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a backend group in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.UpdateBackendGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified backend group."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.DeleteBackendGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified backend group."""

    AddBackend: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.AddBackendRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds backends to the specified backend group."""

    RemoveBackend: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.RemoveBackendRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes backends from the specified backend group."""

    UpdateBackend: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.UpdateBackendRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified backend."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupOperationsRequest,
        yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupOperationsResponse,
    ]
    """Lists operations for the specified backend group."""

class BackendGroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing backend groups."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.GetBackendGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.backend_group_pb2.BackendGroup, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.backend_group_pb2.BackendGroup]]:
        """Returns the specified backend group.

        To get the list of all available backend groups, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupsResponse, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupsResponse]]:
        """Lists backend groups in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.CreateBackendGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a backend group in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.UpdateBackendGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified backend group."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.DeleteBackendGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified backend group."""

    @abc.abstractmethod
    def AddBackend(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.AddBackendRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds backends to the specified backend group."""

    @abc.abstractmethod
    def RemoveBackend(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.RemoveBackendRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes backends from the specified backend group."""

    @abc.abstractmethod
    def UpdateBackend(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.UpdateBackendRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified backend."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.backend_group_service_pb2.ListBackendGroupOperationsResponse]]:
        """Lists operations for the specified backend group."""

def add_BackendGroupServiceServicer_to_server(servicer: BackendGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.storage_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DefaultStorage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    STORAGES_FIELD_NUMBER: builtins.int
    configuration_id: builtins.str
    """ID of the configuration.

    To get the configuration ID, use a [ConfigurationService.List] request.
    """
    @property
    def storages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.storage_pb2.Storage]:
        """List of default storages."""

    def __init__(
        self,
        *,
        configuration_id: builtins.str = ...,
        storages: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.storage_pb2.Storage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["configuration_id", b"configuration_id", "storages", b"storages"]) -> None: ...

global___DefaultStorage = DefaultStorage

@typing.final
class GetDefaultStorageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    configuration_id: builtins.str
    """ID of the configuration."""
    def __init__(
        self,
        *,
        configuration_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["configuration_id", b"configuration_id"]) -> None: ...

global___GetDefaultStorageRequest = GetDefaultStorageRequest

@typing.final
class BatchGetDefaultStoragesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATION_IDS_FIELD_NUMBER: builtins.int
    @property
    def configuration_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of configuration IDs."""

    def __init__(
        self,
        *,
        configuration_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["configuration_ids", b"configuration_ids"]) -> None: ...

global___BatchGetDefaultStoragesRequest = BatchGetDefaultStoragesRequest

@typing.final
class BatchGetDefaultStoragesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_STORAGES_FIELD_NUMBER: builtins.int
    @property
    def default_storages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DefaultStorage]:
        """List of default storages."""

    def __init__(
        self,
        *,
        default_storages: collections.abc.Iterable[global___DefaultStorage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default_storages", b"default_storages"]) -> None: ...

global___BatchGetDefaultStoragesResponse = BatchGetDefaultStoragesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/quotamanager/v1/quota_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/quotamanager/v1/quota_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.quotamanager.v1 import resource_pb2 as yandex_dot_cloud_dot_quotamanager_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/quotamanager/v1/quota_request.proto\x12\x1cyandex.cloud.quotamanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+yandex/cloud/quotamanager/v1/resource.proto\"\xe9\x05\n\x0cQuotaRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x38\n\x08resource\x18\x02 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.Resource\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06status\x18\x04 \x01(\x0e\x32\x31.yandex.cloud.quotamanager.v1.QuotaRequest.Status\x12K\n\x0cquota_limits\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.quotamanager.v1.QuotaRequest.QuotaLimit\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x1a\xce\x02\n\nQuotaLimit\x12\x10\n\x08quota_id\x18\x01 \x01(\t\x12\x15\n\rdesired_limit\x18\x02 \x01(\x01\x12\x16\n\x0e\x61pproved_limit\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\x12L\n\x06status\x18\x05 \x01(\x0e\x32<.yandex.cloud.quotamanager.v1.QuotaRequest.QuotaLimit.Status\x12\x0f\n\x07message\x18\x06 \x01(\t\x12\x13\n\x0bmodified_by\x18\x07 \x01(\t\"}\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\x14\n\x10PARTIAL_APPROVED\x10\x03\x12\x0c\n\x08\x41PPROVED\x10\x04\x12\x0c\n\x08REJECTED\x10\x05\x12\x0c\n\x08\x43\x41NCELED\x10\x06\"h\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\r\n\tPROCESSED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05J\x04\x08\x06\x10\x07\x42q\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.quotamanager.v1.quota_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanager'
  _globals['_QUOTAREQUEST']._serialized_start=161
  _globals['_QUOTAREQUEST']._serialized_end=906
  _globals['_QUOTAREQUEST_QUOTALIMIT']._serialized_start=460
  _globals['_QUOTAREQUEST_QUOTALIMIT']._serialized_end=794
  _globals['_QUOTAREQUEST_QUOTALIMIT_STATUS']._serialized_start=669
  _globals['_QUOTAREQUEST_QUOTALIMIT_STATUS']._serialized_end=794
  _globals['_QUOTAREQUEST_STATUS']._serialized_start=796
  _globals['_QUOTAREQUEST_STATUS']._serialized_end=900
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/licensemanager/saas/v1/instance_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/licensemanager/saas/v1/instance_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.marketplace.licensemanager.v1 import instance_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_instance__pb2
from yandex.cloud.marketplace.licensemanager.v1 import user_info_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_user__info__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFyandex/cloud/marketplace/licensemanager/saas/v1/instance_service.proto\x12/yandex.cloud.marketplace.licensemanager.saas.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x39yandex/cloud/marketplace/licensemanager/v1/instance.proto\x1a:yandex/cloud/marketplace/licensemanager/v1/user_info.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x12GetInstanceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x12GetUserInfoRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xb5\x03\n\x0fInstanceService\x12\xc6\x01\n\x03Get\x12\x43.yandex.cloud.marketplace.licensemanager.saas.v1.GetInstanceRequest\x1a\x34.yandex.cloud.marketplace.licensemanager.v1.Instance\"D\x82\xd3\xe4\x93\x02>\x12</marketplace/license-manager/saas/v1/instances/{instance_id}\x12\xd8\x01\n\x0bGetUserInfo\x12\x43.yandex.cloud.marketplace.licensemanager.saas.v1.GetUserInfoRequest\x1a\x34.yandex.cloud.marketplace.licensemanager.v1.UserInfo\"N\x82\xd3\xe4\x93\x02H\x12\x46/marketplace/license-manager/saas/v1/instances/{instance_id}/user_infoB\x99\x01\n3yandex.cloud.api.marketplace.licensemanager.saas.v1Zbgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/saas/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.marketplace.licensemanager.saas.v1Zbgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/saas/v1;licensemanager'
  _globals['_GETINSTANCEREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_GETINSTANCEREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUSERINFOREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_GETUSERINFOREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _globals['_INSTANCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002>\022</marketplace/license-manager/saas/v1/instances/{instance_id}'
  _globals['_INSTANCESERVICE'].methods_by_name['GetUserInfo']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['GetUserInfo']._serialized_options = b'\202\323\344\223\002H\022F/marketplace/license-manager/saas/v1/instances/{instance_id}/user_info'
  _globals['_GETINSTANCEREQUEST']._serialized_start=303
  _globals['_GETINSTANCEREQUEST']._serialized_end=350
  _globals['_GETUSERINFOREQUEST']._serialized_start=352
  _globals['_GETUSERINFOREQUEST']._serialized_end=399
  _globals['_INSTANCESERVICE']._serialized_start=402
  _globals['_INSTANCESERVICE']._serialized_end=839
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/catalog_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/catalog_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.trino.v1 import catalog_pb2 as yandex_dot_cloud_dot_trino_dot_v1_dot_catalog__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/trino/v1/catalog_service.proto\x12\x15yandex.cloud.trino.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a#yandex/cloud/trino/v1/catalog.proto\x1a\x1dyandex/cloud/validation.proto\"W\n\x11GetCatalogRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\ncatalog_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x91\x01\n\x13ListCatalogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"a\n\x14ListCatalogsResponse\x12\x30\n\x08\x63\x61talogs\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.trino.v1.Catalog\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"s\n\x14\x43reateCatalogRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x39\n\x07\x63\x61talog\x18\x02 \x01(\x0b\x32\".yandex.cloud.trino.v1.CatalogSpecB\x04\xe8\xc7\x31\x01\"?\n\x15\x43reateCatalogMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\"\xd2\x01\n\x14UpdateCatalogRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\ncatalog_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12?\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32(.yandex.cloud.trino.v1.CatalogUpdateSpecB\x04\xe8\xc7\x31\x01\"?\n\x15UpdateCatalogMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\"Z\n\x14\x44\x65leteCatalogRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\ncatalog_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"?\n\x15\x44\x65leteCatalogMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t2\x9e\x07\n\x0e\x43\x61talogService\x12\x96\x01\n\x03Get\x12(.yandex.cloud.trino.v1.GetCatalogRequest\x1a\x1e.yandex.cloud.trino.v1.Catalog\"E\x82\xd3\xe4\x93\x02?\x12=/managed-trino/v1/clusters/{cluster_id}/catalogs/{catalog_id}\x12\x99\x01\n\x04List\x12*.yandex.cloud.trino.v1.ListCatalogsRequest\x1a+.yandex.cloud.trino.v1.ListCatalogsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/managed-trino/v1/clusters/{cluster_id}/catalogs\x12\xb9\x01\n\x06\x43reate\x12+.yandex.cloud.trino.v1.CreateCatalogRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2* \n\x15\x43reateCatalogMetadata\x12\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x35\"0/managed-trino/v1/clusters/{cluster_id}/catalogs:\x01*\x12\xc6\x01\n\x06Update\x12+.yandex.cloud.trino.v1.UpdateCatalogRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2* \n\x15UpdateCatalogMetadata\x12\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x42\x32=/managed-trino/v1/clusters/{cluster_id}/catalogs/{catalog_id}:\x01*\x12\xd1\x01\n\x06\x44\x65lete\x12+.yandex.cloud.trino.v1.DeleteCatalogRequest\x1a!.yandex.cloud.operation.Operation\"w\xb2\xd2*.\n\x15\x44\x65leteCatalogMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?*=/managed-trino/v1/clusters/{cluster_id}/catalogs/{catalog_id}B\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.catalog_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_GETCATALOGREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCATALOGREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCATALOGREQUEST'].fields_by_name['catalog_id']._loaded_options = None
  _globals['_GETCATALOGREQUEST'].fields_by_name['catalog_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCATALOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCATALOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCATALOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCATALOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCATALOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCATALOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCATALOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCATALOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECATALOGREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECATALOGREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECATALOGREQUEST'].fields_by_name['catalog']._loaded_options = None
  _globals['_CREATECATALOGREQUEST'].fields_by_name['catalog']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECATALOGREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECATALOGREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECATALOGREQUEST'].fields_by_name['catalog_id']._loaded_options = None
  _globals['_UPDATECATALOGREQUEST'].fields_by_name['catalog_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECATALOGREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATECATALOGREQUEST'].fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECATALOGREQUEST'].fields_by_name['catalog']._loaded_options = None
  _globals['_UPDATECATALOGREQUEST'].fields_by_name['catalog']._serialized_options = b'\350\3071\001'
  _globals['_DELETECATALOGREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECATALOGREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECATALOGREQUEST'].fields_by_name['catalog_id']._loaded_options = None
  _globals['_DELETECATALOGREQUEST'].fields_by_name['catalog_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CATALOGSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002?\022=/managed-trino/v1/clusters/{cluster_id}/catalogs/{catalog_id}'
  _globals['_CATALOGSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0022\0220/managed-trino/v1/clusters/{cluster_id}/catalogs'
  _globals['_CATALOGSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateCatalogMetadata\022\007Catalog\202\323\344\223\0025\"0/managed-trino/v1/clusters/{cluster_id}/catalogs:\001*'
  _globals['_CATALOGSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateCatalogMetadata\022\007Catalog\202\323\344\223\002B2=/managed-trino/v1/clusters/{cluster_id}/catalogs/{catalog_id}:\001*'
  _globals['_CATALOGSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteCatalogMetadata\022\025google.protobuf.Empty\202\323\344\223\002?*=/managed-trino/v1/clusters/{cluster_id}/catalogs/{catalog_id}'
  _globals['_GETCATALOGREQUEST']._serialized_start=276
  _globals['_GETCATALOGREQUEST']._serialized_end=363
  _globals['_LISTCATALOGSREQUEST']._serialized_start=366
  _globals['_LISTCATALOGSREQUEST']._serialized_end=511
  _globals['_LISTCATALOGSRESPONSE']._serialized_start=513
  _globals['_LISTCATALOGSRESPONSE']._serialized_end=610
  _globals['_CREATECATALOGREQUEST']._serialized_start=612
  _globals['_CREATECATALOGREQUEST']._serialized_end=727
  _globals['_CREATECATALOGMETADATA']._serialized_start=729
  _globals['_CREATECATALOGMETADATA']._serialized_end=792
  _globals['_UPDATECATALOGREQUEST']._serialized_start=795
  _globals['_UPDATECATALOGREQUEST']._serialized_end=1005
  _globals['_UPDATECATALOGMETADATA']._serialized_start=1007
  _globals['_UPDATECATALOGMETADATA']._serialized_end=1070
  _globals['_DELETECATALOGREQUEST']._serialized_start=1072
  _globals['_DELETECATALOGREQUEST']._serialized_end=1162
  _globals['_DELETECATALOGMETADATA']._serialized_start=1164
  _globals['_DELETECATALOGMETADATA']._serialized_end=1227
  _globals['_CATALOGSERVICE']._serialized_start=1230
  _globals['_CATALOGSERVICE']._serialized_end=2156
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Episode(google.protobuf.message.Message):
    """Entity representing a stream fragment that can be accessed independently.
    Episodes can be linked to either a stream or a line
    and provide a way to reference specific portions of the corresponding content.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _VisibilityStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VisibilityStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Episode._VisibilityStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VISIBILITY_STATUS_UNSPECIFIED: Episode._VisibilityStatus.ValueType  # 0
        """The visibility status is not specified."""
        PUBLISHED: Episode._VisibilityStatus.ValueType  # 1
        """The episode is publicly available, subject to its access permission settings."""
        UNPUBLISHED: Episode._VisibilityStatus.ValueType  # 2
        """The episode is available only to administrators."""

    class VisibilityStatus(_VisibilityStatus, metaclass=_VisibilityStatusEnumTypeWrapper):
        """Visibility status of the episode."""

    VISIBILITY_STATUS_UNSPECIFIED: Episode.VisibilityStatus.ValueType  # 0
    """The visibility status is not specified."""
    PUBLISHED: Episode.VisibilityStatus.ValueType  # 1
    """The episode is publicly available, subject to its access permission settings."""
    UNPUBLISHED: Episode.VisibilityStatus.ValueType  # 2
    """The episode is available only to administrators."""

    ID_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    DVR_SECONDS_FIELD_NUMBER: builtins.int
    VISIBILITY_STATUS_FIELD_NUMBER: builtins.int
    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the episode."""
    stream_id: builtins.str
    """Identifier of the stream this episode is linked to.
    Optional, empty if the episode is linked to a line.
    """
    line_id: builtins.str
    """Identifier of the line this episode is linked to.
    Optional, empty if the episode is linked to a stream.
    """
    title: builtins.str
    """Title of the episode displayed in interfaces and players."""
    description: builtins.str
    """Detailed description of the episode content and context."""
    thumbnail_id: builtins.str
    """Identifier of the thumbnail image used to represent the episode visually."""
    dvr_seconds: builtins.int
    """Controls the Digital Video Recording (DVR) functionality for the episode.
    Determines how many seconds of the stream are available for time-shifted viewing.

    Possible values:
     * `0`: Infinite DVR size, the full length of the stream is available for viewing.
     * `>0`: Size of DVR window in seconds, the minimum value is 30s.
    """
    visibility_status: global___Episode.VisibilityStatus.ValueType
    """Current visibility status controlling whether the episode is publicly available."""
    style_preset_id: builtins.str
    """Identifier of the style preset used in the player during episode playback."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp marking the beginning of the episode content."""

    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp marking the end of the episode content."""

    @property
    def public_access(self) -> global___EpisodePublicAccessRights:
        """Allows unrestricted public access to the episode via direct link.
        No additional authorization or access control is applied.
        """

    @property
    def sign_url_access(self) -> global___EpisodeSignURLAccessRights:
        """Restricts episode access using URL signatures for secure time-limited access."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the episode was initially created in the system."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the last modification to the episode or its metadata."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        stream_id: builtins.str = ...,
        line_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        dvr_seconds: builtins.int = ...,
        visibility_status: global___Episode.VisibilityStatus.ValueType = ...,
        style_preset_id: builtins.str = ...,
        public_access: global___EpisodePublicAccessRights | None = ...,
        sign_url_access: global___EpisodeSignURLAccessRights | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "created_at", b"created_at", "finish_time", b"finish_time", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "created_at", b"created_at", "description", b"description", "dvr_seconds", b"dvr_seconds", "finish_time", b"finish_time", "id", b"id", "line_id", b"line_id", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time", "stream_id", b"stream_id", "style_preset_id", b"style_preset_id", "thumbnail_id", b"thumbnail_id", "title", b"title", "updated_at", b"updated_at", "visibility_status", b"visibility_status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...

global___Episode = Episode

@typing.final
class EpisodePublicAccessRights(google.protobuf.message.Message):
    """Represents public access rights for an episode.
    When this access type is set, the episode is publicly accessible via direct link.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EpisodePublicAccessRights = EpisodePublicAccessRights

@typing.final
class EpisodeSignURLAccessRights(google.protobuf.message.Message):
    """Represents access rights controlled by URL signatures.
    When this access type is set, the episode is accessible only via properly signed temporary link.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EpisodeSignURLAccessRights = EpisodeSignURLAccessRights



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/common/transceiver_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/common/transceiver_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/cic/v1/common/transceiver_type.proto\x12\x1ayandex.cloud.cic.v1.common*\xdd\x01\n\x0fTransceiverType\x12 \n\x1cTRANSCEIVER_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cTRANSCEIVER_TYPE_1000BASE_LX\x10\x01\x12\x1f\n\x1bTRANSCEIVER_TYPE_10GBASE_LR\x10\x02\x12\x1f\n\x1bTRANSCEIVER_TYPE_10GBASE_ER\x10\x03\x12!\n\x1dTRANSCEIVER_TYPE_100GBASE_LR4\x10\x04\x12!\n\x1dTRANSCEIVER_TYPE_100GBASE_ER4\x10\x05\x42\x64\n\x1eyandex.cloud.api.cic.v1.commonZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1/common;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.common.transceiver_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.cic.v1.commonZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1/common;cic'
  _globals['_TRANSCEIVERTYPE']._serialized_start=82
  _globals['_TRANSCEIVERTYPE']._serialized_end=303
# @@protoc_insertion_point(module_scope)
